pynrc.maths.coords
==================

.. automodule:: pynrc.maths.coords

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      Tel2Sci_info
      oversampled_coords
      siafap_sci_coords
   
   

   
   
   

   
   
   



